.. _Nipype: http://nipype.readthedocs.io/en/latest/
.. _BIDS: http://bids.neuroimaging.io
.. _`BIDS Derivatives`: https://bids-specification.readthedocs.io/en/stable/05-derivatives/01-introduction.html
.. _`BEP 011`: https://bids-specification.readthedocs.io/en/bep011/05-derivatives/04-structural-derivatives.html
.. _Installation: installation.html
.. _workflows: workflows.html
.. _FreeSurfer: https://surfer.nmr.mgh.harvard.edu/
.. _AFNI: https://afni.nimh.nih.gov/
.. _GIFTI: https://www.nitrc.org/projects/gifti/
.. _niworkflows:  https://www.nipreps.org/niworkflows/



